@@ -35,8 +35,8 @@ import org.eclipse.ui.part.DrillDownAdapter;
 import org.eclipse.ui.part.ViewPart;
 
 /**
- * Tree viewer class used to construct a view on the local history store. The 
- * tree navigates over the actual contents of the history store rather than 
+ * Tree viewer class used to construct a view on the local history store. The
+ * tree navigates over the actual contents of the history store rather than
  * going to the navigator and asking each file for its list of file states. This allows
  * the browser to see the deleted files for containers.
  */
@@ -239,12 +239,7 @@ public class LocalHistoryBrowserView extends ViewPart {
 	private void hookContextMenu() {
 		MenuManager menuMgr = new MenuManager("#PopupMenu"); //$NON-NLS-1$
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				LocalHistoryBrowserView.this.fillContextMenu(manager);
-			}
-		});
+		menuMgr.addMenuListener(LocalHistoryBrowserView.this::fillContextMenu);
 		Menu menu = menuMgr.createContextMenu(viewer.getControl());
 		viewer.getControl().setMenu(menu);
 		getSite().registerContextMenu(menuMgr, viewer);
@@ -312,12 +307,7 @@ public class LocalHistoryBrowserView extends ViewPart {
 	}
 
 	private void hookDoubleClickAction() {
-		viewer.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				doubleClickAction.run();
-			}
-		});
+		viewer.addDoubleClickListener(event -> doubleClickAction.run());
 	}
 
 	protected void showMessage(String message) {
