@@ -18,8 +18,6 @@ package org.eclipse.core.tests.resources;
 import java.io.*;
 import java.nio.charset.StandardCharsets;
 import java.util.*;
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.core.internal.events.NotificationManager;
 import org.eclipse.core.internal.preferences.EclipsePreferences;
 import org.eclipse.core.internal.resources.CharsetDeltaJob;
@@ -123,26 +121,6 @@ public class CharsetTest extends ResourceTest {
 
 	private String savedWorkspaceCharset;
 
-	public static Test suite() {
-		//		TestSuite suite = new TestSuite();
-		//		suite.addTest(new CharsetTest("testFileCreation"));
-		//		suite.addTest(new CharsetTest("testPrefsFileCreation"));
-		//		return suite;
-		//		return new CharsetTest("testMovingProject");
-
-		return new TestSuite(CharsetTest.class);
-
-		//    // cause the same test to run several times to catch a timing problem
-		//		TestSuite suite = new TestSuite();
-		//		for (int i = 0; i < 1000; i++)
-		//			suite.addTest(new CharsetTest("testDeltasFile"));
-		//		return suite;
-	}
-
-	public CharsetTest(String name) {
-		super(name);
-	}
-
 	/**
 	 * See bug 67606.
 	 *
@@ -419,7 +397,6 @@ public class CharsetTest extends ResourceTest {
 	 * Test for getting charset on an IFile:
 	 * #getContentDescription() checks file sync state(), always returning the
 	 * correct content description, whereas getCharset() uses the cached charset if available.
-	 * @throws Exception
 	 */
 	public void testBug186984() throws Exception {
 		getResourcesPreferences().putBoolean(ResourcesPlugin.PREF_LIGHTWEIGHT_AUTO_REFRESH, false);
