@@ -16,8 +16,6 @@ package org.eclipse.core.tests.resources;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.core.internal.resources.Workspace;
 import org.eclipse.core.resources.*;
 import org.eclipse.core.runtime.*;
@@ -53,21 +51,6 @@ public class IResourceChangeListenerTest extends ResourceTest {
 	IFile project2MetaData;
 	ResourceDeltaVerifier verifier;
 
-	public static Test suite() {
-		//	TestSuite suite = new TestSuite();
-		//	suite.addTest(new IResourceChangeListenerTest("testMoveProject1"));
-		//	return suite;
-		return new TestSuite(IResourceChangeListenerTest.class);
-	}
-
-	public IResourceChangeListenerTest() {
-		super();
-	}
-
-	public IResourceChangeListenerTest(String name) {
-		super(name);
-	}
-
 	public void _testBenchMark_1GBYQEZ() {
 		// start with a clean workspace
 		getWorkspace().removeResourceChangeListener(verifier);
@@ -178,9 +161,7 @@ public class IResourceChangeListenerTest extends ResourceTest {
 				}
 				return true;
 			});
-		} catch (CoreException e) {
-			fail(message, e);
-		} catch (RuntimeException e) {
+		} catch (CoreException | RuntimeException e) {
 			fail(message, e);
 		}
 	}
@@ -304,9 +285,7 @@ public class IResourceChangeListenerTest extends ResourceTest {
 			//wait for autobuild so POST_BUILD will fire
 			try {
 				Job.getJobManager().join(ResourcesPlugin.FAMILY_AUTO_BUILD, null);
-			} catch (OperationCanceledException e) {
-				//ignore
-			} catch (InterruptedException e) {
+			} catch (OperationCanceledException | InterruptedException e) {
 				//ignore
 			}
 		} catch (CoreException e) {
